@@ -65,7 +65,7 @@ struct _EvApplicationClass {
 G_DEFINE_TYPE (EvApplication, ev_application, GTK_TYPE_APPLICATION)
 
 #ifdef ENABLE_DBUS
-#define APPLICATION_DBUS_NAME        "org.gnome.evince.Application"
+#define APPLICATION_NAME             "org.gnome.Evince"
 #define APPLICATION_DBUS_OBJECT_PATH "/org/gnome/evince/Evince"
 #define APPLICATION_DBUS_INTERFACE   "org.gnome.evince.Application"
 
@@ -103,7 +103,7 @@ ev_application_new (void)
   const GApplicationFlags flags = G_APPLICATION_NON_UNIQUE;
 
   return g_object_new (EV_TYPE_APPLICATION,
-                       "application-id", APPLICATION_DBUS_NAME,
+                       "application-id", APPLICATION_NAME,
                        "flags", flags,
                        NULL);
 }
@@ -993,7 +993,7 @@ app_about_cb (GSimpleAction *action,
                                "authors", authors,
                                "documenters", documenters,
                                "translator-credits", _("translator-credits"),
-                               "logo-icon-name", "evince",
+                               "logo-icon-name", "org.gnome.Evince",
                                NULL);
 }
 
