@@ -31,7 +31,6 @@
 #include "ev-zoom-action.h"
 #include "ev-application.h"
 #include "ev-page-action-widget.h"
-#include "ev-sidebar.h"
 #include <math.h>
 
 enum
@@ -51,7 +50,6 @@ struct _EvToolbarPrivate {
         GtkWidget *open_button;
         GtkWidget *annots_button;
         GtkWidget *sidebar_button;
-        GtkWidget *sidebar;
 
         EvToolbarMode toolbar_mode;
 };
@@ -157,27 +155,6 @@ zoom_selector_activated (GtkWidget *zoom_action,
         ev_window_focus_view (toolbar->priv->window);
 }
 
-static void
-ev_toolbar_sidebar_current_page_changed (EvSidebar  *ev_sidebar,
-                                         GParamSpec *pspec,
-                                         EvToolbar  *ev_toolbar)
-{
-        GtkWidget *button = ev_toolbar->priv->sidebar_button;
-        GtkWidget *image;
-        gchar     *icon_name;
-
-        g_object_get (ev_sidebar, "active-icon-name", &icon_name, NULL);
-
-        if (!icon_name)
-                return;
-
-        image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
-
-        gtk_widget_set_valign (button, GTK_ALIGN_CENTER);
-        gtk_button_set_image (GTK_BUTTON (button), image);
-        g_free (icon_name);
-}
-
 static void
 ev_toolbar_find_button_sensitive_changed (GtkWidget  *find_button,
 					  GParamSpec *pspec,
@@ -214,14 +191,14 @@ ev_toolbar_constructed (GObject *object)
 
         /* Sidebar */
         button = ev_toolbar_create_toggle_button (ev_toolbar, "win.show-side-pane",
-                                                  "view-grid-symbolic",
+                                                  EV_STOCK_VIEW_SIDEBAR,
                                                   _("Side pane"));
         ev_toolbar->priv->sidebar_button = button;
         gtk_header_bar_pack_start (GTK_HEADER_BAR (ev_toolbar), button);
 
         /* Page selector */
         /* Use EvPageActionWidget for now, since the page selector action is also used by the previewer */
-        tool_item = ev_page_action_widget_new (G_MENU (gtk_builder_get_object (builder, "navigation-menu")));
+        tool_item = GTK_WIDGET (g_object_new (EV_TYPE_PAGE_ACTION_WIDGET, NULL));
         gtk_widget_set_tooltip_text (tool_item, _("Select page or search in the index"));
         atk_object_set_name (gtk_widget_get_accessible (tool_item), _("Select page"));
         ev_toolbar->priv->page_selector = tool_item;
@@ -245,6 +222,16 @@ ev_toolbar_constructed (GObject *object)
         ev_toolbar->priv->action_menu_button = button;
         gtk_header_bar_pack_end (GTK_HEADER_BAR (ev_toolbar), button);
 
+        /* Find */
+        button = ev_toolbar_create_toggle_button (ev_toolbar, "win.toggle-find", "edit-find-symbolic",
+                                                  NULL);
+        ev_toolbar->priv->find_button = button;
+        gtk_header_bar_pack_end (GTK_HEADER_BAR (ev_toolbar), button);
+        g_signal_connect (button,
+                          "notify::sensitive",
+                          G_CALLBACK (ev_toolbar_find_button_sensitive_changed),
+                          ev_toolbar);
+
         /* Zoom selector */
         vbox = ev_zoom_action_new (ev_window_get_document_model (ev_toolbar->priv->window),
                                    G_MENU (gtk_builder_get_object (builder, "zoom-menu")));
@@ -256,16 +243,6 @@ ev_toolbar_constructed (GObject *object)
                           ev_toolbar);
         gtk_header_bar_pack_end (GTK_HEADER_BAR (ev_toolbar), vbox);
 
-        /* Find */
-        button = ev_toolbar_create_toggle_button (ev_toolbar, "win.toggle-find", "edit-find-symbolic",
-                                                  NULL);
-        ev_toolbar->priv->find_button = button;
-        gtk_header_bar_pack_end (GTK_HEADER_BAR (ev_toolbar), button);
-        g_signal_connect (button,
-                          "notify::sensitive",
-                          G_CALLBACK (ev_toolbar_find_button_sensitive_changed),
-                          ev_toolbar);
-
         g_object_unref (builder);
 }
 
@@ -324,9 +301,6 @@ ev_toolbar_has_visible_popups (EvToolbar *ev_toolbar)
         if (ev_zoom_action_get_popup_shown (EV_ZOOM_ACTION (ev_toolbar->priv->zoom_action)))
                 return TRUE;
 
-        if (ev_page_action_widget_get_popup_shown (EV_PAGE_ACTION_WIDGET (ev_toolbar->priv->page_selector)))
-                return TRUE;
-
         return FALSE;
 }
 
@@ -388,18 +362,3 @@ ev_toolbar_get_mode (EvToolbar *ev_toolbar)
 
         return ev_toolbar->priv->toolbar_mode;
 }
-
-void
-ev_toolbar_set_sidebar (EvToolbar *ev_toolbar,
-                        GtkWidget *sidebar)
-{
-        g_return_if_fail (EV_IS_TOOLBAR (ev_toolbar));
-        g_return_if_fail (EV_IS_SIDEBAR (sidebar));
-
-        ev_toolbar->priv->sidebar = sidebar;
-
-        g_signal_connect (sidebar,
-                          "notify::current-page",
-                          G_CALLBACK (ev_toolbar_sidebar_current_page_changed),
-                          ev_toolbar);
-}
